"""
Allows for tracking current stage of in-progress DAGs.
"""
import argparse
from argparse import ArgumentParser
import datetime
import htchirp


def parser() -> ArgumentParser:
    """
    Initialize argument parser for CLI

    :return: ArgumentParser
    """
    parser = ArgumentParser(
        description="Update Stage allows for tracking the current stage of in-progress workflows",
        formatter_class=argparse.RawTextHelpFormatter,
    )
    parser.add_argument(
        "stage",
        type=str,
        action="store",
        help="the stage name of the running workflow",
    )
    parser.add_argument(
        "--complete",
        action="store_true",
        help="this stage is complete",
    )

    return parser


def send_update(message: str):
    """
    Make use of HTCondor Chirp Protocol to update stage

    :param message: the dict containing message parameters
    """
    with htchirp.HTChirp() as chirp:
        chirp.ulog(message)


def build_message(args: argparse.Namespace) -> str:
    """
    Build message dict

    :param args:
    :return:
    """
    if args.complete:
        state = "Completed"
    else:
        state = "Started"

    time = datetime.datetime.now()

    return f"WS STAGE UPDATE: Stage {str(args.stage).upper()} has {state} at {time}."


def main():
    """
    Run update

    :return:
    """

    args = parser().parse_args()

    message = build_message(args)
    send_update(message)
